Index: branches/single_player_map/src/world_entities/space_ships/spacecraft_2d.cc
===================================================================
--- branches/single_player_map/src/world_entities/space_ships/turbine_hover.cc	(revision 9011)
+++ branches/single_player_map/src/world_entities/space_ships/spacecraft_2d.cc	(revision 9045)
@@ -17,5 +17,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_WORLD_ENTITY
 
-#include "turbine_hover.h"
+#include "spacecraft_2d.h"
 
 #include "weapons/weapon_manager.h"
@@ -34,10 +34,10 @@
 #include "debug.h"
 
-CREATE_FACTORY(TurbineHover, CL_TURBINE_HOVER);
-
-/**
- *  destructs the turbine_hover, deletes alocated memory
+CREATE_FACTORY(Spacecraft2D, CL_SPACECRAFT_2D);
+
+/**
+ *  destructs the spacecraft_2d, deletes alocated memory
  */
-TurbineHover::~TurbineHover ()
+Spacecraft2D::~Spacecraft2D ()
 {
   this->setPlayer(NULL);
@@ -45,8 +45,8 @@
 
 /**
  * @brief loads a TurbineHover information from a specified file.
  * @param fileName the name of the File to load the turbine_hover from (absolute path)
  */
-TurbineHover::TurbineHover(const std::string& fileName)
+Spacecraft2D::Spacecraft2D(const std::string& fileName)
 {
   this->init();
@@ -55,5 +55,5 @@
   if(!doc.LoadFile())
   {
-    PRINTF(2)("Loading file %s failed for TurbineHover.\n", fileName.c_str());
+    PRINTF(2)("Loading file %s failed for Spacecraft2D.\n", fileName.c_str());
     return;
   }
@@ -68,5 +68,5 @@
    @todo add more parameters to load
 */
-TurbineHover::TurbineHover(const TiXmlElement* root)
+Spacecraft2D::Spacecraft2D(const TiXmlElement* root)
 {
   this->init();
@@ -95,10 +95,10 @@
 
 /**
- * @brief initializes a TurbineHover
+ * @brief initializes a Spacecraft2D
  */
-void TurbineHover::init()
+void Spacecraft2D::init()
 {
   //  this->setRelDir(Quaternion(M_PI, Vector(1,0,0)));
-  this->setClassID(CL_TURBINE_HOVER, "TurbineHover");
+  this->setClassID(CL_SPACECRAFT_2D, "Spacecraft2D");
 
   this->setSupportedPlaymodes(Playable::Full3D | Playable::Horizontal | Playable::Vertical);
@@ -150,5 +150,5 @@
   this->burstEmitter[0]->setRelCoor(0, -0.7, 0);
   this->burstEmitter[0]->setRelDir(Quaternion(-M_PI_2, Vector(0,0,1)));
-  this->burstEmitter[0]->setName("TurbineHover_Burst_emitter_Left");
+  this->burstEmitter[0]->setName("Spacecraft2D_Burst_emitter_Left");
 
   this->burstEmitter[1] = new DotEmitter(200, 5.0, .01);
@@ -156,5 +156,5 @@
   this->burstEmitter[1]->setRelCoor(0, -0.7, 0);
   this->burstEmitter[1]->setRelDir(Quaternion(-M_PI_2, Vector(0,0,1)));
-  this->burstEmitter[1]->setName("TurbineHover_Burst_emitter_Right");
+  this->burstEmitter[1]->setName("Spacecraft2D_Burst_emitter_Right");
 
 
@@ -211,5 +211,5 @@
   this->getWeaponManager().getFixedTarget()->setParent(&this->cameraNode);
   this->getWeaponManager().getFixedTarget()->setRelCoor(1000,0,0);
-  
+
   registerVar( new SynchronizeableBool( &bForward, &bForward, "bForward", PERMISSION_OWNER ) );
   registerVar( new SynchronizeableBool( &bBackward, &bBackward, "bBackward", PERMISSION_OWNER ) );
@@ -224,18 +224,18 @@
 
 /**
  * @brief loads the Settings of a TurbineHover from an XML-element.
  * @param root the XML-element to load the Spaceship's properties from
  */
-void TurbineHover::loadParams(const TiXmlElement* root)
+void Spacecraft2D::loadParams(const TiXmlElement* root)
 {
   Playable::loadParams(root);
 }
 
-void TurbineHover::setPlayDirection(const Quaternion& rot, float speed)
+void Spacecraft2D::setPlayDirection(const Quaternion& rot, float speed)
 {
   this->direction = Quaternion (rot.getHeading(), Vector(0,1,0));
 }
 
-void TurbineHover::enter()
+void Spacecraft2D::enter()
 {
   dynamic_cast<Element2D*>(this->getWeaponManager().getFixedTarget())->setVisibility( true);
@@ -249,5 +249,5 @@
 }
 
-void TurbineHover::leave()
+void Spacecraft2D::leave()
 {
   dynamic_cast<Element2D*>(this->getWeaponManager().getFixedTarget())->setVisibility( false);
@@ -258,7 +258,7 @@
 
 /**
  * @brief effect that occurs after the TurbineHover is spawned
 */
-void TurbineHover::postSpawn ()
+void Spacecraft2D::postSpawn ()
 {
   //setCollision(new CollisionCluster(1.0, Vector(0,0,0)));
@@ -266,7 +266,7 @@
 
 /**
  * @brief the action occuring if the turbine_hover left the game
 */
-void TurbineHover::leftWorld ()
+void Spacecraft2D::leftWorld ()
 {}
 
@@ -277,5 +277,5 @@
  * Implement behaviour like damage application or other miscellaneous collision stuff in this function
  */
-void TurbineHover::collidesWith(WorldEntity* entity, const Vector& location)
+void Spacecraft2D::collidesWith(WorldEntity* entity, const Vector& location)
 {
   Playable::collidesWith(entity, location);
@@ -288,5 +288,5 @@
  * @param time The timespan passed since last update
 */
-void TurbineHover::tick (float dt)
+void Spacecraft2D::tick (float dt)
 {
   //  this->debugNode(1);
@@ -306,5 +306,5 @@
  * @param time the timeslice since the last frame
 */
-void TurbineHover::movement (float dt)
+void Spacecraft2D::movement (float dt)
 {
   Vector accel(0.0, 0.0, 0.0);
@@ -433,5 +433,5 @@
 
 
-void TurbineHover::draw() const
+void Spacecraft2D::draw() const
 {
   Vector tmpRot;
@@ -486,5 +486,5 @@
  * @todo switch statement ??
  */
-void TurbineHover::process(const Event &event)
+void Spacecraft2D::process(const Event &event)
 {
   Playable::process(event);
@@ -45,8 +45,8 @@
 
 /**
- * @brief loads a TurbineHover information from a specified file.
- * @param fileName the name of the File to load the turbine_hover from (absolute path)
+ * @brief loads a Spacecraft2D information from a specified file.
+ * @param fileName the name of the File to load the spacecraft_2d from (absolute path)
  */
@@ -224,18 +224,18 @@
 
 /**
- * @brief loads the Settings of a TurbineHover from an XML-element.
+ * @brief loads the Settings of a Spacecraft2D from an XML-element.
  * @param root the XML-element to load the Spaceship's properties from
  */
@@ -258,7 +258,7 @@
 
 /**
- * @brief effect that occurs after the TurbineHover is spawned
+ * @brief effect that occurs after the Spacecraft2D is spawned
 */
@@ -266,7 +266,7 @@
 
 /**
- * @brief the action occuring if the turbine_hover left the game
+ * @brief the action occuring if the spacecraft_2d left the game
 */
